from distutils.core import setup
setup(
    name='GBComments',
    version='0.0.1',
    py_modules=['GBComments'],
    author="WRAllen",
    author_email="1072274105@qq.com",
    description="这是一个好评差评的包",
)